@@ -1,4 +1,4 @@
-class Error(Exception):
+class BaseError(Exception):
     """
     Attributes:
         response_content: Response content from logic monitor
@@ -17,16 +17,16 @@ class Error(Exception):
         self.msg = msg
 
 
-class InvalidItemsError(Error):
+class InvalidNumOfItemsError(BaseError):
     """ Raised when the number of expected items returned from logicmonitor is not correct """
     pass
 
 
-class RequestFailedError(Error):
+class RequestFailedError(BaseError):
     """ If return status code is not ok """
     pass
 
 
-class ItemNotAvailable(Error):
-    """ If the the item is not available on logicmonitor """
+class ItemNotFoundError(BaseError):
+    """ If the the item is not found on logicmonitor """
     pass
